figure (1, "visible", "off");

global demos
global count

function retval = input ()
  global demos
  global count
  retval = num2str (demos (count++));
endfunction

demos = [1 : 7, 1 : 7, 8 : 15];
count = 1;
tsademo;

invfdemo;

bisdemo;

